@@ -834,6 +834,12 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
 
         vAPI.storage.set({ 'availableFilterLists': µb.availableFilterLists });
 
+        logger.writeOne({
+            realm: 'message',
+            type: 'info',
+            text: 'Reloading all filter lists: done'
+        });
+
         vAPI.messaging.broadcast({
             what: 'staticFilteringDataChanged',
             parseCosmeticFilters: µb.userSettings.parseAllABPHideFilters,
@@ -865,6 +871,12 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
     };
 
     const onFilterListsReady = lists => {
+        logger.writeOne({
+            realm: 'message',
+            type: 'info',
+            text: 'Reloading all filter lists: start'
+        });
+
         µb.availableFilterLists = lists;
 
         if ( vAPI.Net.canSuspend() ) {
@@ -1039,8 +1051,9 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
         this.hiddenSettings.filterAuthorMode !== false;
     const parser = new sfp.AstFilterParser({
         expertMode,
-        nativeCssHas: vAPI.webextFlavor.env.includes('native_css_has'),
+        filterOnHeaders: µb.hiddenSettings.filterOnHeaders,
         maxTokenLength: staticNetFilteringEngine.MAX_TOKEN_LENGTH,
+        nativeCssHas: vAPI.webextFlavor.env.includes('native_css_has'),
     });
     const compiler = staticNetFilteringEngine.createCompiler(parser);
     const lineIter = new LineIterator(
@@ -1122,7 +1135,7 @@ self.addEventListener('hiddenSettingsChanged', ( ) => {
 
         const fetcher = (path, options = undefined) => {
             if ( path.startsWith('/web_accessible_resources/') ) {
-                path += `?secret=${vAPI.warSecret()}`;
+                path += `?secret=${vAPI.warSecret.short()}`;
                 return io.fetch(path, options);
             }
             return io.fetchText(path);
